@@ -14,7 +14,6 @@ from cfchecker import cfchecks
 from numpy import ma
 
 from . import utils
-from .utils import str2num
 from .version import __version__
 
 FILE_PATH = os.path.dirname(os.path.realpath(__file__))
@@ -71,9 +70,15 @@ class FileReport:
 
 def run_tests(filename: Path, cloudnet_file_type: Optional[str] = None) -> dict:
     with netCDF4.Dataset(filename) as nc:
-        cloudnet_file_type = (
-            cloudnet_file_type if cloudnet_file_type is not None else nc.cloudnet_file_type
-        )
+        if cloudnet_file_type is None:
+            try:
+                cloudnet_file_type = nc.cloudnet_file_type
+            except AttributeError:
+                logging.error(
+                    "No cloudnet_file_type global attribute found, can not run tests. "
+                    "Is this a legacy file?"
+                )
+                return {}
         logging.debug(f"Filename: {filename.stem}")
         logging.debug(f"File type: {cloudnet_file_type}")
         test_reports: List[Dict] = []
@@ -220,6 +225,10 @@ class TestGlobalAttributes(Test):
 class TestMedianLwp(Test):
     def run(self):
         key = "lwp"
+        if key not in self.nc.variables:
+            self.severity = ErrorLevel.ERROR
+            self._add_message(f"'{key}' is missing.")
+            return
         limits = [-0.5, 10]
         median_lwp = ma.median(self.nc.variables[key][:]) / 1000  # g -> kg
         if median_lwp < limits[0] or median_lwp > limits[1]:
@@ -231,10 +240,14 @@ class TestMedianLwp(Test):
 class FindVariableOutliers(Test):
     def run(self):
         for key, limits_str in DATA_CONFIG.items("limits"):
-            limits = [str2num(x) for x in limits_str.split(",")]
+            limits = [float(x) for x in limits_str.split(",")]
             if key in self.nc.variables:
-                max_value = np.max(self.nc.variables[key][:])
-                min_value = np.min(self.nc.variables[key][:])
+                data = self.nc.variables[key][:]
+                if data.ndim > 0 and len(data) == 0:
+                    self.severity = ErrorLevel.ERROR
+                    break
+                max_value = np.max(data)
+                min_value = np.min(data)
                 if min_value < limits[0]:
                     msg = utils.create_out_of_bounds_msg(key, *limits, min_value)
                     self._add_message(msg)
@@ -247,9 +260,9 @@ class FindVariableOutliers(Test):
 class FindAttributeOutliers(Test):
     def run(self):
         for key, limits_str in METADATA_CONFIG.items("attribute_limits"):
-            limits = [str2num(x) for x in limits_str.split(",")]
+            limits = [float(x) for x in limits_str.split(",")]
             if hasattr(self.nc, key):
-                value = str2num(self.nc.getncattr(key))
+                value = float(self.nc.getncattr(key))
                 if value < limits[0] or value > limits[1]:
                     msg = utils.create_out_of_bounds_msg(key, *limits, value)
                     self._add_message(msg)
@@ -282,8 +295,14 @@ class TestLDR(Test):
 @test("Test radar folding", products=[Product.RADAR, Product.CATEGORIZE])
 class FindFolding(Test):
     def run(self):
+        key = "v"
         v_threshold = 8
-        data = self.nc["v"][:]
+        try:
+            data = self.nc[key][:]
+        except IndexError:
+            self.severity = ErrorLevel.ERROR
+            self._add_message(f"Doppler velocity, '{key}', is missing.")
+            return
         difference = np.abs(np.diff(data, axis=1))
         n_suspicious = ma.sum(difference > v_threshold)
         if n_suspicious > 20:
@@ -331,7 +350,15 @@ class TestInstrumentPid(Test):
 class TestTimeVector(Test):
     def run(self):
         time = self.nc["time"][:]
-        if time.shape == () or len(time) == 1:
+        try:
+            n_time = len(time)
+        except (TypeError, ValueError):
+            self._add_message("Time vector is empty.")
+            return
+        if n_time == 0:
+            self._add_message("Time vector is empty.")
+            return
+        if n_time == 1:
             self._add_message("One time step only.")
             return
         differences = np.diff(time)
